@@ -17,7 +17,11 @@ import string
 import copy
 from copy import deepcopy
 import re
-import h5py
+
+try:
+    import h5py
+except ModuleNotFoundError:
+    print('warning: h5py is missing. It is useful for playing with hdf5 for some LaueTools modules. Install it with pip> pip install h5py')
 
 import numpy as np
 
@@ -30,7 +34,7 @@ if sys.version_info.major == 3:
 else:
     from dict_LaueTools import CST_ENERGYKEV, CCD_CALIBRATION_PARAMETERS
     PYTHON3 = False
-    print('-- OK! you are using python 2 but tetter install python 3')
+    print('-- OK! you are using python 2 but you would better install python 3')
 
 DEFAULT_CCDLABEL = 'sCMOS'
 
@@ -1857,8 +1861,8 @@ def parsehdf5time(strtime):
     starttime = time.strptime('%s %s %s %s:%s:%s'%(yy, mm, dd, hh, mi, sec[:2]), '%Y %m %d %H:%M:%S')
     return time.asctime(starttime), time.mktime(starttime)
 
-def ReadHdf5(fname, scan, outputdate=False):
-    """extrct data of a scan in a ESRF Bliss made hdf5 file
+def ReadHdf5_v2(fname, scan, outputdate=False):
+    """extract data of a scan in a ESRF Bliss made hdf5 file
 
     :param fname: file object or string (path)
     :type fname: file object or string
@@ -1867,32 +1871,135 @@ def ReadHdf5(fname, scan, outputdate=False):
     :param outputdate: output starting date of the scan in ascii format, defaults to False
     :type outputdate: bool, optional
     """
-    if isinstance(fname, str):
-        f = h5py.File(fname, 'r')
+    os.environ["HDF5_USE_FILE_LOCKING"] = "FALSE"
 
-    i_scan = '%d' % scan + '.1'
-    print('i_scan', i_scan)
-    print('fname', f)
-    print('fname[i_scan]', f[i_scan])
-    datasetnames = [key for key in f[i_scan]['measurement'].keys()]
-    d = {}
-    for _n in datasetnames:
-        d[_n] = f[i_scan]['measurement'][_n].value
-    # x =  f[i_scan]['measurement']['m0'].value
-    # y = f[i_scan]['measurement']['m1'].value
-    # z = f[i_scan]['measurement']['fluo1'].value
-    title = f[i_scan]['title'].value
-    st = f[i_scan]['start_time'].value
-    et = f[i_scan]['end_time'].value
-    duration = parsehdf5time(et)[1] - parsehdf5time(st)[1]
-    
-    print('title', title)
-    print('duration', duration)
-    
-    if not outputdate:
-        return title, d
+    with h5py.File(fname, 'r') as f:
+
+        i_scan = '%d' % scan + '.1'
+        print('i_scan', i_scan)
+        print('fname', f)
+        print('fname[i_scan]', f[i_scan])
+        datasetnames = [key for key in f[i_scan]['measurement'].keys()]
+        d = {}
+        for _n in datasetnames:
+            d[_n] = f[i_scan]['measurement'][_n][()]
+
+        if h5py.__version__>='3':
+            title = f[i_scan]['title'][()].decode('UTF-8')
+            st = f[i_scan]['start_time'][()].decode('UTF-8')
+            et = f[i_scan]['end_time'][()].decode('UTF-8')
+        else:
+            title = f[i_scan]['title'].value
+            st = f[i_scan]['start_time'].value
+            et = f[i_scan]['end_time'].value
+        duration = parsehdf5time(et)[1] - parsehdf5time(st)[1]
+        
+        print('title', title)
+        print('duration', duration)
+        
+        if not outputdate:
+            return title, d
+        else:
+            return title, d, st
+
+def readdata_from_hdf5key(listkeyprops, key, outputdate=False):
+    """access to a low level hdf5 file and read data corresponding to the key 
+
+    :param listkeyprops: array of strings which lists all the keys (see getmeshscan_from_hdf5file() of plotmeshspecGUI.py). Each element is:
+    props=['%s_%s'%(keyfilename,idx),idx, postfix, startdate, '%s_%s %s'%(keyfilename, idx, scancommand), filename]
+    :type fname: file object or string
+    :param scan: string for scan id  (key in hdf5 file)
+    :type scan: integer
+    :param outputdate: output starting date of the scan in ascii format, defaults to False
+    :type outputdate: bool, optional
+    """
+    # print('key',key)
+    # print('listkeyprops[:,0]',listkeyprops[:,0])
+
+    _ix = np.where(listkeyprops[:,0]==key)[0]
+
+    # print('_ix',_ix)
+    # print('listkeyprops[_ix]', listkeyprops[_ix])
+
+    if len(_ix)==0:
+        title ='Not Reachable'
+        d={}
+        st =''
     else:
-        return title, d, st
+        assert len(_ix)==1
+        general_id, idx, postfix, startdate, commandtitle, fullpath = listkeyprops[_ix[0]]
+        
+        os.environ["HDF5_USE_FILE_LOCKING"] = "FALSE"
+        with h5py.File(fullpath, 'r') as f:
+
+            i_scan = '%s.%s'%(idx, postfix)
+            # print('i_scan', i_scan)
+            # print('fname', f)
+            # print('fname[i_scan]', f[i_scan])
+            datasetnames = [key for key in f[i_scan]['measurement'].keys()]
+            d = {}
+            for _n in datasetnames:
+                d[_n] = f[i_scan]['measurement'][_n][()]
+            
+            if h5py.__version__>='3':
+                title = f[i_scan]['title'][()].decode('UTF-8')
+                st = f[i_scan]['start_time'][()].decode('UTF-8')
+                et = f[i_scan]['end_time'][()].decode('UTF-8')
+            else:
+                title = f[i_scan]['title'].value
+                st = f[i_scan]['start_time'].value
+                et = f[i_scan]['end_time'].value
+            duration = parsehdf5time(et)[1] - parsehdf5time(st)[1]
+            
+            print('title', title)
+            print('duration', duration)
+            
+        if not outputdate:
+            return title, d
+        else:
+            return title, d, st
+
+
+def ReadHdf5(fname, scan, outputdate=False):
+    """extract data of a scan in a ESRF Bliss made hdf5 file when key are formatted as int.1
+
+    :param fname: file object or string (path)
+    :type fname: file object or string
+    :param scan: string for scan id  (key in hdf5 file)
+    :type scan: integer
+    :param outputdate: output starting date of the scan in ascii format, defaults to False
+    :type outputdate: bool, optional
+    """
+    os.environ["HDF5_USE_FILE_LOCKING"] = "FALSE"
+
+    with h5py.File(fname, 'r') as f:
+
+        i_scan = '%d' % scan + '.1'
+        print('i_scan', i_scan)
+        print('fname', f)
+        print('fname[i_scan]', f[i_scan])
+        datasetnames = [key for key in f[i_scan]['measurement'].keys()]
+        d = {}
+        for _n in datasetnames:
+            d[_n] = f[i_scan]['measurement'][_n][()]
+
+        if h5py.__version__>='3':
+            title = f[i_scan]['title'][()].decode('UTF-8')
+            st = f[i_scan]['start_time'][()].decode('UTF-8')
+            et = f[i_scan]['end_time'][()].decode('UTF-8')
+        else:
+            title = f[i_scan]['title'].value
+            st = f[i_scan]['start_time'].value
+            et = f[i_scan]['end_time'].value
+        duration = parsehdf5time(et)[1] - parsehdf5time(st)[1]
+        
+        print('title', title)
+        print('duration', duration)
+        
+        if not outputdate:
+            return title, d
+        else:
+            return title, d, st
 
 
 def ReadSpec(fname, scan, outputdate=False):
